@@ -5,7 +5,6 @@ from neosctl import util
 from neosctl.auth import ensure_login
 from neosctl.util import process_response
 
-
 app = typer.Typer()
 
 
@@ -18,8 +17,8 @@ def query(
     ctx: typer.Context,
     statement: str,
 ):
-    """Query a published data product.
-    """
+    """Query a published data product."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
