@@ -6,12 +6,11 @@ import typing
 import httpx
 import typer
 
-from neosctl import util
+from neosctl import constant, util
 from neosctl.auth import ensure_login
 from neosctl.schema import DataProductCreate
 from neosctl.util import process_response
 
-
 app = typer.Typer()
 
 
@@ -37,13 +36,14 @@ def template(
 
     Given a csv with a header row, generate a template field schema.
     """
+
     @ensure_login
     def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
         params = {k: v for k, v in [("delimiter", delimiter), ("quotechar", quotechar)] if v is not None}
 
         return util.post(
             ctx,
-            "{dp_url}/template".format(dp_url=product_url(ctx)),
+            f"{product_url(ctx)}/template",
             params=params,
             files={"csv_file": f},
         )
@@ -53,10 +53,10 @@ def template(
     with fp.open("rb") as f:
         r = _request(ctx, f)
 
-    if r.status_code >= 400:
+    if r.status_code >= constant.BAD_REQUEST_CODE:
         process_response(r)
 
-    fp = pathlib.Path(output_dir) / "{}.json".format(name)
+    fp = pathlib.Path(output_dir) / f"{name}.json"
     with fp.open("w") as f:
         json.dump(r.json(), f, indent=4)
 
@@ -68,13 +68,13 @@ def create_from_json(
     engine: str = typer.Option(..., "--engine", "-e", help="Storage engine"),
     filepath: str = typer.Option(..., "--filepath", "-f", help="Filepath of the table schema json payload"),
 ):
-    """Create a data product.
-    """
+    """Create a data product."""
+
     @ensure_login
     def _request(ctx: typer.Context, dpc: DataProductCreate) -> httpx.Response:
         return util.post(
             ctx,
-            "{dp_url}/{name}".format(dp_url=product_url(ctx), name=name),
+            f"{product_url(ctx)}/{name}",
             json=dpc.dict(exclude_none=True),
         )
 
@@ -87,10 +87,10 @@ def create_from_json(
     process_response(r)
 
 
-@app.command()
-def list(ctx: typer.Context):
-    """List data products.
-    """
+@app.command(name="list")
+def list_products(ctx: typer.Context):
+    """List data products."""
+
     @ensure_login
     def _request(ctx: typer.Context):
         return util.get(ctx, product_url(ctx))
@@ -104,13 +104,13 @@ def delete_data(
     ctx: typer.Context,
     name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Delete data from a data product.
-    """
+    """Delete data from a data product."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            "{dp_url}/{name}/data".format(dp_url=product_url(ctx), name=name),
+            f"{product_url(ctx)}/{name}/data",
         )
 
     r = _request(ctx)
@@ -127,13 +127,13 @@ def delete(
         help="Force remove even if attached spark application is still running.",
     ),
 ):
-    """Delete a data product.
-    """
+    """Delete a data product."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            "{dp_url}/{name}".format(dp_url=product_url(ctx), name=name),
+            f"{product_url(ctx)}/{name}",
             params={"force": force},
         )
 
@@ -146,13 +146,13 @@ def publish(
     ctx: typer.Context,
     name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Publish a data product.
-    """
+    """Publish a data product."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
             ctx,
-            "{dp_url}/{name}/publish".format(dp_url=product_url(ctx), name=name),
+            f"{product_url(ctx)}/{name}/publish",
         )
 
     r = _request(ctx)
@@ -164,13 +164,13 @@ def unpublish(
     ctx: typer.Context,
     name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Unpublish a product.
-    """
+    """Unpublish a product."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            "{dp_url}/{name}/publish".format(dp_url=product_url(ctx), name=name),
+            f"{product_url(ctx)}/{name}/publish",
         )
 
     r = _request(ctx)
@@ -182,13 +182,13 @@ def get_product(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Get data product schema.
-    """
+    """Get data product schema."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{dp_url}/{name}".format(dp_url=product_url(ctx), name=product_name),
+            f"{product_url(ctx)}/{product_name}",
         )
 
     r = _request(ctx)
@@ -204,6 +204,7 @@ def preview(
 
     Get the first 25 rows of a data product's data.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
