@@ -5,12 +5,7 @@ import click
 import typer
 
 from neosctl import schema
-from neosctl.util import get_user_profile_section
-from neosctl.util import prettify_json
-from neosctl.util import remove_config
-from neosctl.util import send_output
-from neosctl.util import upsert_config
-
+from neosctl.util import get_user_profile_section, prettify_json, remove_config, send_output, upsert_config
 
 app = typer.Typer()
 
@@ -21,7 +16,8 @@ r = re.compile(r"http[s]?:\/\/.*")
 def validate_url(value):
     m = r.match(value)
     if m is None:
-        raise click.UsageError("Invalid url, must match pattern: `{}`.".format(r))
+        msg = f"Invalid url, must match pattern: `{r}`."
+        raise click.UsageError(msg)
     return value
 
 
@@ -52,8 +48,8 @@ def init(
 
     Call `init` on an existing profile will update the existing profile.
     """
-    typer.echo("Initialising [{}] profile.".format(ctx.obj.profile_name))
-    default_host = "{}/api/{{}}".format(hostname) if hostname else ""
+    typer.echo(f"Initialising [{ctx.obj.profile_name}] profile.")
+    default_host = f"{hostname}/api/{{}}" if hostname else ""
 
     if non_interactive and not (hostname and username):
         send_output(
@@ -62,10 +58,10 @@ def init(
         )
 
     if non_interactive:
-        gateway_api_url = gateway_api_url or "{}/api/gateway".format(hostname)
-        storage_api_url = storage_api_url or "{}/api/storage".format(hostname)
-        iam_api_url = iam_api_url or "{}/api/iam".format(hostname)
-        registry_api_url = registry_api_url or "{}/api/registry".format(hostname)
+        gateway_api_url = gateway_api_url or f"{hostname}/api/gateway"
+        storage_api_url = storage_api_url or f"{hostname}/api/storage"
+        iam_api_url = iam_api_url or f"{hostname}/api/iam"
+        registry_api_url = registry_api_url or f"{hostname}/api/registry"
 
     urls = {
         "gateway_api_url": gateway_api_url,
@@ -79,7 +75,7 @@ def init(
         ("iam", ctx.obj.get_iam_api_url(), "IAM API url"),
         ("storage", ctx.obj.get_storage_api_url(), "Storage API url"),
     ]:
-        url_key = "{}_api_url".format(key)
+        url_key = f"{key}_api_url"
         if urls[url_key] is None:
             urls[url_key] = typer.prompt(
                 prompt,
@@ -98,7 +94,7 @@ def init(
             **kwargs,
         )
 
-    profile = schema.Profile(
+    profile = schema.Profile(  # nosec: B106
         user=username,
         access_token="",
         refresh_token="",
@@ -113,9 +109,8 @@ def init(
 def delete(
     ctx: typer.Context,
 ):
-    """Delete a profile.
-    """
-    typer.confirm("Remove [{}] profile".format(ctx.obj.profile_name), abort=True)
+    """Delete a profile."""
+    typer.confirm(f"Remove [{ctx.obj.profile_name}] profile", abort=True)
     remove_config(ctx)
 
 
@@ -123,19 +118,17 @@ def delete(
 def view(
     ctx: typer.Context,
 ):
-    """View configuration for a profile.
-    """
+    """View configuration for a profile."""
     send_output(
         msg=prettify_json({**get_user_profile_section(ctx.obj.config, ctx.obj.profile_name)}),
     )
 
 
-@app.command()
-def list(
+@app.command(name="list")
+def list_profiles(
     ctx: typer.Context,
 ):
-    """List available profiles.
-    """
+    """List available profiles."""
     send_output(
         msg=prettify_json(sorted(ctx.obj.config.sections())),
     )
