@@ -3,11 +3,9 @@ import typer
 
 from neosctl import util
 from neosctl.auth import ensure_login
-from neosctl.schema import RegisterCore
-from neosctl.schema import RemoveCore
+from neosctl.schema import RegisterCore, RemoveCore
 from neosctl.util import process_response
 
-
 app = typer.Typer()
 
 
@@ -27,10 +25,11 @@ def register_core(
 ):
     """Register a core.
 
-    Register a core to recieve an identifier and access key for use in deployment.
+    Register a core to receive an identifier and access key for use in deployment.
     """
+
     @ensure_login
-    def _request(ctx: typer.Context, name: str, rc: RegisterCore) -> httpx.Response:
+    def _request(ctx: typer.Context, rc: RegisterCore) -> httpx.Response:
         return util.post(
             ctx,
             core_url(ctx.obj.get_registry_api_url()),
@@ -39,7 +38,7 @@ def register_core(
 
     rc = RegisterCore(partition=partition, name=name)
 
-    r = _request(ctx, name, rc)
+    r = _request(ctx, rc)
     process_response(r)
 
 
@@ -47,8 +46,8 @@ def register_core(
 def list_cores(
     ctx: typer.Context,
 ):
-    """List existing registered cores.
-    """
+    """List existing registered cores."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
@@ -65,8 +64,8 @@ def remove_core(
     ctx: typer.Context,
     urn: str = typer.Argument(..., help="Core urn"),
 ):
-    """Remove a registered core.
-    """
+    """Remove a registered core."""
+
     @ensure_login
     def _request(ctx: typer.Context, rc: RemoveCore) -> httpx.Response:
         return util.delete(
@@ -86,8 +85,8 @@ def search_products(
     ctx: typer.Context,
     search_term: str,
 ):
-    """Search published data products across cores.
-    """
+    """Search published data products across cores."""
+
     @ensure_login
     def _request(ctx: typer.Context, search_term: str) -> httpx.Response:
         return util.get(
@@ -105,13 +104,13 @@ def get_product(
     ctx: typer.Context,
     urn: str,
 ):
-    """Get data product details.
-    """
+    """Get data product details."""
+
     @ensure_login
     def _request(ctx: typer.Context, urn: str) -> httpx.Response:
         return util.get(
             ctx,
-            data_product_url(ctx.obj.get_registry_api_url(), "/urn/{}".format(urn)),
+            data_product_url(ctx.obj.get_registry_api_url(), f"/urn/{urn}"),
         )
 
     r = _request(ctx, urn)
